# Changelog
所有显著的更改都将记录在此文件中。

## [0.1] - 2024-01-13

## Added

- 添加日志文件

### Changed
- 取消指定库的依赖版本


## [0.2.5] - 2024-01-13

### Fixed
- 修复了项目运行目录获取错误的问题

## [0.2.0] - 2024-01-13

和0.1.0版本完全不兼容，不推荐使用0.1.0的版本

### Added
- 添加了更多的使用例子
